@@ -1,5 +1,5 @@
 from django.apps import AppConfig
-from django.utils.translation import ugettext_lazy as t
+from django.utils.translation import gettext_lazy as t
 
 
 class JoeflowConfig(AppConfig):
